function frames = load_frames(filename, frmNos)
%extract a bunch of frames from a .pmd file - note that in keeping
%with matlab format, the first frame is frame one!!!!


%convert into integers
frmNos = uint32(frmNos);
numFramesRequested = length(frmNos);

if any(frmNos <= 0),
  error('Frame numbers must be positive');
elseif ~isequal(sort(frmNos), frmNos),
  error('Frame numbers must be extracted in sequence order');
end

%store the output here
frames = cell(1, numFramesRequested);

hnd = pmdOpen('pmdfile.W32.pcp', filename, ...
              'camcubeproc.W32.ppp', '');

%need one first call
pmdUpdate(hnd);

cellIdx = 1;

%frame number we are actually on
n = 1;

for frameWeWant = frmNos,
  %fprintf('extracting frame %d\n', frameWeWant);

  difference = frameWeWant - n;
  skip_frames(hnd, difference);
  n = frameWeWant;
  
  %could maybe add some metadata here?
  meta = struct('frameno', frameWeWant);
  frames{cellIdx} = ...
      struct('pointCloud', single(pmdGet3DCoordinates(hnd)), ...
             'dists', single(pmdGetDistances(hnd)), ...
             'amplitudes', single(pmdGetAmplitudes(hnd)), ...
             'intensities', single(pmdGetIntensities(hnd)), ...
             'meta', meta);
  cellIdx = cellIdx + 1;
end

pmdClose(hnd);
