function gb = gabor_wavelet(sigma, theta, lambda, psi, gamma)
% Creates a gabor wavelet filter
% sigma - Gaussian envelope width
% theta - orientation of the parallel stripes of a Gabor function
% lambda - wavelength of the sinusoidal factor
% psi - phase offset
% gamma - aspect ratio

sigma_x = sigma;
sigma_y = sigma / gamma;

nstds = 3;
xMax = max(abs(nstds * sigma_x * cos(theta)), ...
           abs(nstds * sigma_y * sin(theta)));
xMax = ceil(max(1, xMax));

yMax = max(abs(nstds * sigma_x * sin(theta)), ...
           abs(nstds * sigma_y * cos(theta)));
yMax = ceil(max(1, yMax));

xMin = -xMax;
yMin = -yMax;
[x,y] = meshgrid(xMin:xMax, yMin:yMax);

x_theta =  x*cos(theta) + y*sin(theta);
y_theta = -x*sin(theta) + y*cos(theta);

gb = 1/(2*pi*sigma_x*sigma_y) * ...
     exp(-.5*(x_theta.^2/sigma_x^2 + y_theta.^2/sigma_y^2)) .* ...
     cos(2*pi/lambda*x_theta + psi);
