function distances = laplacian_filter(distances, size)
%Applies the Laplacian filter of specified size to an image

filter = [];

if size == 3,
  %or should this be:
  %filter = [0 1 0; 1 -4 1; 0 1 0];
  filter = [1 1 1; 1 -8 1; 1 1 1];
elseif size == 5,
  filter = zeros(5,5);
  limit = 2;
  offs = 3;
  sigma = 0.5;
  for x=[-limit:limit],
    for y=[-limit:limit],
      %formula from http://homepages.inf.ed.ac.uk/rbf/HIPR2/log.htm
      tmp = (x^2 + y^2) / (2 * sigma^2);
      filter(x+offs,y+offs) = (-1/(pi * sigma^4)) * (1 - tmp) * exp(-tmp);
    end
  end
elseif size == 7,
  filter = zeros(7,7);
  limit = 3;
  offs = 4;
  sigma = 0.7;
  for x=[-limit:limit],
    for y=[-limit:limit],
      %formula from http://homepages.inf.ed.ac.uk/rbf/HIPR2/log.htm
      tmp = (x^2 + y^2) / (2 * sigma^2);
      filter(x+offs,y+offs) = (-1/(pi * sigma^4)) * (1 - tmp) * exp(-tmp);
    end
  end  
else
  error('unsupported size');
end

%return the same size, need to cut out the valid bits later
distances = filter2(filter, distances, 'same');